### Name: SyNet-package
### Title: Inference and Analysis of Sympatry Networks
### Aliases: SyNet-package SyNet
### Keywords: package

### ** Examples

data(sciobius2x2)

#####
# Derive a sympatry matrix. >=1 for co-occurrence in at least one location.
sm <- as.matrix(sciobius2x2)%*%t(as.matrix((sciobius2x2)))
# Plot a sympatry network
forgraph <- seq(0, by = 2*pi/47, length = 47)
xcoord <- cos(forgraph)
ycoord <- sin(forgraph)
par(mfrow = c(2,2))
plot(xcoord, ycoord, main = "Basal Sympatry Network", 
sub = "Non-significant Node Ordering", xlab = "", ylab = "")
text (xcoord*1.05, ycoord*1.05, rownames(sciobius2x2))
for (i in 1:46) 
  for (j in (i+1):47)
    if(sm[i,j] > 0) lines (c(xcoord[i], xcoord[j]), c(ycoord[i], ycoord[j]))
# The layout is sub-optimal, and it seems chaotic. But as Saramago says:
# 'Chaos is an order that has not been already decoded'.

#####
# Now, we order the nodes according to their NAM Status. 
namsc <- nam(gridinfer(dntable = sciobius2x2))
codenam <- as.integer(namsc$Categories[,3])
neworder <- order(codenam)
plot(xcoord, ycoord, main = "Basal Sympatry Network",
sub = "NAM Node Ordering", xlab = "", ylab = "" )
text (xcoord*1.05, ycoord*1.05, namsc$Categories[neworder,1])
for (i in 1:46) 
  for (j in (i+1):47) 
     if(sm[neworder[i],neworder[j]] > 0) 
       lines (c(xcoord[i], xcoord[j]), c(ycoord[i], ycoord[j]))
  
#####
# Finally, we delete links inciding on those nodes classified 
# as isolated or intermediary ones.
plot(xcoord, ycoord, main = "Selected Sub-network", 
sub = "Units of Co-occurrence", xlab = "", ylab = "" )
text (xcoord*1.05, ycoord*1.05, namsc$Categories[neworder,1])
for (i in 1:46){ 
  if (codenam[neworder[i]] < 1) next
  for (j in (i+1):47) {
    if (codenam[neworder[j]] < 1) 
      next
    if(sm[neworder[i],neworder[j]] > 0) 
      lines (c(xcoord[i], xcoord[j]), c(ycoord[i], ycoord[j]))
  }
}




